OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "text document" : "teksdokument",
    "File not found" : "Lêer nie gevind nie",
    "Readme" : "Leesmy",
    "Text" : "Teks",
    "📝 Collaborative document editing" : "📝 Samewerkende dokumentredigering",
    "Reconnect" : "Herverbind",
    "Guest" : "Gas",
    "you" : "u",
    "edit" : "edigeer",
    "guest" : "gas",
    "Offline" : "Vanlyn",
    "Saving …" : "Bewaar tans…",
    "Saved" : "Bewaar",
    "Unsaved changes" : "Onbewaarde veranderinge",
    "Keyboard shortcuts" : "Sneltoetse",
    "Bold" : "Vet",
    "Italic" : "Skuins",
    "Strikethrough" : "Deurstreep",
    "Heading 1" : "Kop 1",
    "Heading 6" : "Kop 6",
    "Unordered list" : "Ongesorteerde lys",
    "Ordered list" : "Gesorteerde lys",
    "Blockquote" : "Blokaanhaling",
    "Cancel" : "Cancel",
    "Save" : "Stoor",
    "to" : "aan",
    "Edit" : "Wysig",
    "Upload" : "Oplaai",
    "Headings" : "Koppe",
    "Heading 2" : "Kop 2",
    "Heading 3" : "Kop 3",
    "Heading 4" : "Kop 4",
    "Heading 5" : "Kop 5",
    "Details" : "Besonderhede",
    "Choose" : "Kies"
},
"nplurals=2; plural=(n != 1);");
